<p align="center">
  <a href="https://altern.ai">
    <img src="ast/altern-python.png" alt="Altern For Python" />
  </a>

  <p>Altern API python package</p>
</p>

install
--------

The easiest way to install the altern package is either via pip:

```
$ pip install altern
```

or manually by downloading the source and run the setup.py script:

```
python setup.py install
```

license
-------

MIT
